@@ -8,7 +8,7 @@ test_that("'GgmModel' generates data correctly", {
     max_level <- sample(3:5, 1)
 
     # Nodes.
-    nodes <- sample(10:20)
+    nodes <- sample(10:20, 1)
 
     # Density.
     density <- sample(seq(.2, .5, .1), 1)
@@ -40,7 +40,7 @@ test_that("'GgmModel' generated data matches bootnet data", {
     max_level <- sample(3:5, 1)
 
     # Nodes.
-    nodes <- sample(10:20)
+    nodes <- sample(10:20, 1)
 
     # Density.
     density <- sample(seq(.2, .5, .1), 1)
@@ -75,7 +75,7 @@ test_that("'GgmModel' estimates model parameters correctly", {
     max_level <- sample(3:5, 1)
 
     # Nodes.
-    nodes <- sample(10:20)
+    nodes <- sample(10:20, 1)
 
     # Density.
     density <- sample(seq(.2, .5, .1), 1)
@@ -97,6 +97,12 @@ test_that("'GgmModel' estimates model parameters correctly", {
 
     # The parameters should be identical across both methods.
     expect_equal(network_qgraph, network_ggm_model, ignore_attr = TRUE)
+
+    # Make one variable invariant.
+    data[, 1] <- data[1, 1]
+
+    # Expect the estimation to throw an error due to invariant variables.
+    expect_error(ggm$estimate(data), "Variable\\(s\\) with SD = 0 detected. Increase the sample size.")
 })
 
 
@@ -108,7 +114,7 @@ test_that("'GgmModel' computes the correct measure", {
     max_level <- sample(3:5, 1)
 
     # Nodes.
-    nodes <- sample(10:20)
+    nodes <- sample(10:20, 1)
 
     # Density.
     density <- sample(seq(.2, .5, .1), 1)
